/*
 * Java
 *
 * Copyright 2008-2019 MicroEJ Corp. All rights reserved.
 * For demonstration purpose only.
 * MicroEJ Corp. PROPRIETARY. Use is subject to license terms.
 */
package com.microej.demo.hello;

import java.io.IOException;

import ej.microui.display.Colors;
import ej.microui.display.Display;
import ej.microui.display.Displayable;
import ej.microui.display.GraphicsContext;
import ej.microui.display.Image;
import ej.microui.event.generator.Pointer;
import ej.microui.util.EventHandler;

/**
 * Displays MicroEJ image and a list of "Hello" messages.
 */
public class HelloDisplayable extends Displayable {

	private static final int HOME_PADDING = 10;
	private static final int PADDING_TEXT 					= 5;
	private static final int PADDING_BETWEEN_IMAGE_AND_TEXT = 30;

	private final HelloMessage[] messages;

	private Image microejImage;

	public HelloDisplayable(HelloMessage[] messages) {
		super(Display.getDefaultDisplay());
		this.messages = messages;
		try {
			microejImage = Image.createImage("/com/microej/demo/hello/images/microej.png");
		}
		catch (IOException e) {
			throw new AssertionError(e);
		}
	}

	@Override
	public void paint(GraphicsContext g) {
		// clean
		g.setColor(Colors.WHITE);
		int width = getDisplay().getWidth();
		int height = getDisplay().getHeight();
		g.fillRect(0, 0, width, height);

		// compute vertical center
		int y = height / 2;
		int microejImageHeight = microejImage.getHeight();
		y -= (microejImageHeight + PADDING_BETWEEN_IMAGE_AND_TEXT) / 2;
		for (HelloMessage message : this.messages) {
			y -= (message.getFont().getHeight() + PADDING_TEXT) / 2;
		}

		// draw MicroEJ image
		g.drawImage(microejImage, width / 2, y, GraphicsContext.HCENTER | GraphicsContext.TOP);
		y += microejImageHeight + PADDING_BETWEEN_IMAGE_AND_TEXT;

		// draw each message
		g.setColor(0x262A2C);
		for (HelloMessage message : this.messages) {
			g.setFont(message.getFont());
			g.drawString(message.getHelloString(), width / 2, y, GraphicsContext.HCENTER | GraphicsContext.VCENTER);
			y += message.getFont().getHeight() + PADDING_TEXT;
		}


	}

	@Override
	public EventHandler getController() {
		return null;
	}

	private static boolean isIncluded(Pointer p, int startX, int startY, int width, int height) {
		int x = p.getX();
		int y = p.getY();
		return (x >= startX && x < width + startX) && (y >= startY && y < height + startY);
	}

}
